===============
Configuring HPC
===============

To configure which high-performance computing (HPC) platform
is going to be used, issue the command
:func:`hiperwalk.set_hpc`.

.. currentmodule:: hiperwalk

.. autofunction:: set_hpc
